@@ -69,7 +69,7 @@ impl Translator for DigestTranslator {
         let input = args
             .iter()
             .filter(|arg| arg.tag == "input:data")
-            .flat_map(|arg| ["--input", arg.as_utf8()]);
+            .flat_map(|arg| ["--input", arg.as_str()]);
 
         let keywords = args
             .iter()
@@ -80,14 +80,14 @@ impl Translator for DigestTranslator {
             && keywords.iter().all(|arg| {
                 ENTRIES
                     .iter()
-                    .any(|entry| normalized_eq(arg.as_utf8(), entry.keywords, 0))
+                    .any(|entry| normalized_eq(arg.as_str(), entry.keywords, 0))
             })
         {
             return Some(
                 CommandArgs::new().add_args_iter(input).add_args_iter(
                     keywords
                         .iter()
-                        .flat_map(|arg| ["--algorithm", arg.as_utf8()]),
+                        .flat_map(|arg| ["--algorithm", arg.as_str()]),
                 ),
             );
         }
@@ -121,6 +121,7 @@ impl Command for DigestCommand {
                     blocks: vec![Block::Comment(
                         block::Comment::new().set_text(format!("Unsupprted algorithm: {}", name)),
                     )],
+                    ..Default::default()
                 }
                 .into());
             }
@@ -147,6 +148,7 @@ impl Command for DigestCommand {
             blocks: vec![Block::Comment(
                 block::Comment::new().set_text("No valid input source provided"),
             )],
+            ..Default::default()
         }
         .into())
     }
@@ -177,6 +179,7 @@ fn compute_hash(
                 blocks: vec![Block::Data(
                     block::Data::new().set_text_data(result.join("\n")),
                 )],
+                ..Default::default()
             });
         }
     }
